CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
57 lines
1.4 KiB
C++
57 lines
1.4 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
/*
|
|
This testfile verifies the basic scenario of hipMemPtrGetInfo API
|
|
*/
|
|
#include <hip_test_common.hh>
|
|
struct MemInfo {
|
|
float a;
|
|
int b;
|
|
void* c;
|
|
};
|
|
|
|
/*
|
|
This testcase verifies the basic scenario of
|
|
hipMemPtrGetInfo API
|
|
1. Allocates specific size of memory for the variables
|
|
2. Gets the allocated size of that variable using hipMemPtrGetInfo API
|
|
3. Validates the initial size and allocated size
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipMemPtrGetInfo_Basic) {
|
|
int* iPtr;
|
|
float* fPtr;
|
|
MemInfo* sPtr;
|
|
size_t sSetSize = 1024, sGetSize;
|
|
HIP_CHECK(hipMalloc(&iPtr, sSetSize));
|
|
HIP_CHECK(hipMalloc(&fPtr, sSetSize));
|
|
HIP_CHECK(hipMalloc(&sPtr, sSetSize));
|
|
HIP_CHECK(hipMemPtrGetInfo(iPtr, &sGetSize));
|
|
REQUIRE(sGetSize == sSetSize);
|
|
HIP_CHECK(hipMemPtrGetInfo(fPtr, &sGetSize));
|
|
REQUIRE(sGetSize == sSetSize);
|
|
HIP_CHECK(hipMemPtrGetInfo(sPtr, &sGetSize));
|
|
REQUIRE(sGetSize == sSetSize);
|
|
|
|
HIP_CHECK(hipFree(iPtr));
|
|
HIP_CHECK(hipFree(fPtr));
|
|
HIP_CHECK(hipFree(sPtr));
|
|
}
|
|
|
|
/*
|
|
This testcase verifies the scenario of
|
|
hipMemPtrGetInfo API being called on a zero-sized allocation.
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipMemPtrGetInfo_SizeZeroAllocation) {
|
|
int* iPtr;
|
|
size_t sSetSize = 0, sGetSize;
|
|
HIP_CHECK(hipMalloc(&iPtr, sSetSize));
|
|
HIP_CHECK(hipMemPtrGetInfo(iPtr, &sGetSize));
|
|
REQUIRE(sGetSize == sSetSize);
|
|
|
|
HIP_CHECK(hipFree(iPtr));
|
|
}
|